<?php
session_start();
require_once 'config.php';

// Verificar autenticación
if (!isset($_SESSION['user_id'])) {
    header('Content-Type: application/json');
    echo json_encode(['status' => 'error', 'message' => 'No autenticado']);
    exit();
}

$user_id = $_SESSION['user_id'];
$limit = isset($_GET['limit']) ? intval($_GET['limit']) : 50;
$other_user_id = isset($_GET['other_user_id']) ? intval($_GET['other_user_id']) : 0;

// Construir la consulta SQL
if ($other_user_id) {
    // Obtener historial de llamadas con un usuario específico
    $query = "SELECT c.*, 
                 u1.name as caller_name, 
                 u2.name as receiver_name
              FROM call_logs c
              JOIN users u1 ON c.caller_id = u1.id
              JOIN users u2 ON c.receiver_id = u2.id
              WHERE (c.caller_id = ? AND c.receiver_id = ?) OR (c.caller_id = ? AND c.receiver_id = ?)
              ORDER BY c.start_time DESC
              LIMIT ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("iiiii", $user_id, $other_user_id, $other_user_id, $user_id, $limit);
} else {
    // Obtener historial general de llamadas del usuario
    $query = "SELECT c.*, 
                 u1.name as caller_name, 
                 u2.name as receiver_name
              FROM call_logs c
              JOIN users u1 ON c.caller_id = u1.id
              JOIN users u2 ON c.receiver_id = u2.id
              WHERE c.caller_id = ? OR c.receiver_id = ?
              ORDER BY c.start_time DESC
              LIMIT ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("iii", $user_id, $user_id, $limit);
}

if ($stmt->execute()) {
    $result = $stmt->get_result();
    $calls = [];
    
    while ($row = $result->fetch_assoc()) {
        // Determinar si el usuario actual fue el que llamó o recibió la llamada
        $row['is_outgoing'] = ($row['caller_id'] == $user_id);
        
        // Formatear duración en minutos:segundos
        if ($row['duration']) {
            $minutes = floor($row['duration'] / 60);
            $seconds = $row['duration'] % 60;
            $row['duration_formatted'] = sprintf("%02d:%02d", $minutes, $seconds);
        } else {
            $row['duration_formatted'] = "00:00";
        }
        
        // Formatear fecha para mostrar
        $date = new DateTime($row['start_time']);
        $row['date_formatted'] = $date->format('d/m/Y H:i');
        
        $calls[] = $row;
    }
    
    header('Content-Type: application/json');
    echo json_encode([
        'status' => 'success',
        'calls' => $calls
    ]);
} else {
    header('Content-Type: application/json');
    echo json_encode([
        'status' => 'error',
        'message' => 'Error al obtener historial: ' . $stmt->error
    ]);
}

$stmt->close();
$conn->close();
?>