<?php
session_start();
header('Content-Type: application/json');

// Verificar autenticación
if (!isset($_SESSION['user_id'])) {
    echo json_encode(['success' => false, 'error' => 'No autenticado']);
    exit();
}

// Verificar que se haya enviado un archivo
if (!isset($_FILES['file']) || empty($_FILES['file']['name'])) {
    echo json_encode(['success' => false, 'error' => 'No se ha enviado ningún archivo']);
    exit();
}

// Verificar que se haya especificado un destinatario
if (!isset($_POST['receiver_id']) || !is_numeric($_POST['receiver_id'])) {
    echo json_encode(['success' => false, 'error' => 'ID de receptor inválido']);
    exit();
}

$user_id = $_SESSION['user_id'];
$receiver_id = intval($_POST['receiver_id']);
$file = $_FILES['file'];

// Validar el archivo
$max_file_size = 20 * 1024 * 1024; // 20 MB máximo
if ($file['size'] > $max_file_size) {
    echo json_encode(['success' => false, 'error' => 'El archivo excede el tamaño máximo permitido (20 MB)']);
    exit();
}

// Determinar el tipo de archivo
$file_info = pathinfo($file['name']);
$extension = strtolower($file_info['extension']);
$allowed_extensions = ['jpg', 'jpeg', 'png', 'gif', 'mp4', 'mov', 'pdf', 'doc', 'docx', 'xls', 'xlsx', 'txt'];

if (!in_array($extension, $allowed_extensions)) {
    echo json_encode(['success' => false, 'error' => 'Tipo de archivo no permitido']);
    exit();
}

// Determinar tipo de mensaje
$message_type = 'file';
if (in_array($extension, ['jpg', 'jpeg', 'png', 'gif'])) {
    $message_type = 'image';
    $upload_dir = 'uploads/images/';
} else if (in_array($extension, ['mp4', 'mov'])) {
    $message_type = 'video';
    $upload_dir = 'uploads/videos/';
} else {
    $upload_dir = 'uploads/files/';
}

// Crear directorio si no existe
if (!file_exists($upload_dir)) {
    mkdir($upload_dir, 0755, true);
}

// Generar nombre de archivo único
$new_filename = uniqid() . '_' . $file['name'];
$file_path = $upload_dir . $new_filename;

// Mover archivo
if (!move_uploaded_file($file['tmp_name'], $file_path)) {
    echo json_encode(['success' => false, 'error' => 'Error al guardar el archivo']);
    exit();
}

// Conexión a la base de datos
require_once 'config.php';

// Insertar mensaje con archivo
$query = "INSERT INTO messages (sender_id, receiver_id, message, type, file_url, file_name, file_size, file_type) 
          VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
$stmt = $conn->prepare($query);

$message = isset($_POST['message']) ? trim($_POST['message']) : '';
$stmt->bind_param("iisssssi", $user_id, $receiver_id, $message, $message_type, $file_path, $file['name'], $file['size'], $file['type']);

if ($stmt->execute()) {
    $message_id = $conn->insert_id;
    
    // Construir respuesta
    $response = [
        'success' => true,
        'message_id' => $message_id,
        'type' => $message_type,
        'file' => [
            'url' => $file_path,
            'name' => $file['name'],
            'size' => $file['size'],
            'type' => $file['type']
        ]
    ];
    
    echo json_encode($response);
} else {
    echo json_encode(['success' => false, 'error' => 'Error al registrar el mensaje: ' . $conn->error]);
}

$stmt->close();
$conn->close();
?>